@@ -1,13 +1,4 @@
-/*  cat.c
- *
- *  Transceiver CAT control functions for the xdemorse application
- */
-
 /*
- *  xdemorse: An application to decode and display
- *  Morse code signals using the computer's sound card.
- *
- *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License as
  *  published by the Free Software Foundation; either version 3 of
@@ -45,6 +36,228 @@ static struct termios tcvr_serial_old_options;
 
 /*------------------------------------------------------------------------*/
 
+/* Cancel_CAT()
+ *
+ * Cancels Transceiver CAT (on error)
+ */
+
+  static void
+Cancel_CAT( void )
+{
+  close( serial_fd );
+  serial_fd = 0;
+  //rc_data.tcvr_type = NONE;
+  Clear_Flag( CAT_SETUP );
+  Clear_Flag( TCVR_SERIAL_TEST );
+  Error_Dialog( "Failed to Establish Transceiver CAT"  );
+}
+
+/*-------------------------------------------------------------------------*/
+
+/*  Read_Tcvr_Serial()
+ *
+ *  Reads Data from the Transceiver
+ */
+
+  static gboolean
+Read_Tcvr_Serial( char *data, size_t len )
+{
+  int nbytes = 0, cnt = 0;
+
+  /* Check for data to be available */
+  if( isFlagClear(TCVR_SERIAL_TEST) &&
+	  isFlagClear(CAT_SETUP) )
+	return( FALSE );
+  while( ++cnt < MAX_SERIAL_RETRIES )
+  {
+	ioctl( serial_fd, FIONREAD, &nbytes);
+	if( nbytes == (int)len ) break;
+	fprintf( stderr,
+		"xdemorse: read(): incorrect number of bytes available:"
+		" %d/%d\n", nbytes, (int)len );
+	usleep(100000);
+  }
+
+  /* Error condition */
+  if( cnt >= MAX_SERIAL_RETRIES )
+  {
+	tcflush( serial_fd, TCIOFLUSH );
+	fprintf( stderr,
+		"xdemorse: read(): incorrect number of bytes available:"
+		" %d/%d after %d tries\n", nbytes, (int)len, cnt );
+	data[0] = '\0';
+	Cancel_CAT();
+	return( FALSE );
+  }
+
+  /* Clear data buffer and read from serial */
+  size_t ret = (size_t)read( serial_fd, data, len );
+
+  /* Error condition */
+  if( ret != len )
+  {
+	tcflush( serial_fd, TCIOFLUSH );
+	fprintf( stderr,
+		"xdemorse: read() return value wrong: %d/%d\n",
+		(int)ret, (int)len );
+	data[0] = '\0';
+	Cancel_CAT();
+	return( FALSE );
+  }
+
+  return( TRUE );
+} /* End of Read_Tcvr_Serial() */
+
+/*-------------------------------------------------------------------------*/
+
+/*  Write_Tcvr_Serial()
+ *
+ *  Writes a command to the Tranceiver
+ */
+
+  static gboolean
+Write_Tcvr_Serial( char *data, size_t len )
+{
+  int cnt = 0;
+  size_t ret = 0;
+
+  /* Flush serial and write command, retrying if needed */
+  if( isFlagClear(TCVR_SERIAL_TEST) &&
+	  isFlagClear(CAT_SETUP) )
+	return( FALSE );
+  tcflush( serial_fd, TCIOFLUSH );
+  while( cnt++ < MAX_SERIAL_RETRIES )
+  {
+	ret = (size_t)write( serial_fd, data, len );
+	if( ret == len ) break;
+	fprintf( stderr,
+		"xdemorse: write(): incorrect number of bytes written:"
+		" %d/%d\n", (int)ret, (int)len );
+	usleep(100000);
+  }
+
+  /* Error condition */
+   if( cnt >= MAX_SERIAL_RETRIES )
+  {
+	tcflush( serial_fd, TCIOFLUSH );
+	fprintf( stderr,
+		"xdemorse: write(): incorrect number of bytes written:"
+		" %d/%d after %d tries\n", (int)ret, (int)len, cnt );
+	Cancel_CAT();
+	return( FALSE );
+  }
+
+  /* Give time to CAT to do its thing */
+  usleep(50000);
+  return( TRUE );
+
+} /* End of Write_Tcvr_Serial() */
+
+/*-------------------------------------------------------------------------*/
+
+/*  Read_Rx_Freq()
+ *
+ *  Reads the Rx freq of the Yaesu transceiver.
+ */
+
+  static gboolean
+Read_Rx_Freq( int *freq )
+{
+  /* A char string for sending and receiving  */
+  /* data strings to and from the transceiver */
+  char frq[5];
+
+  /* Abort if CAT disabled */
+  if( isFlagClear(CAT_SETUP) ) return( TRUE );
+
+  switch( rc_data.tcvr_type )
+  {
+	case FT847: case FT857:
+	/* Read Rx frequency */
+	memset( frq, 0, sizeof(frq) );
+	if( !Write_Tcvr_Serial(FT847_MAIN_VFO, sizeof(FT847_MAIN_VFO)) ||
+		!Read_Tcvr_Serial(frq, sizeof(frq)) )
+	  return( FALSE );
+
+	/* Decode frequency data to 10Hz */
+	*freq = 0;
+	*freq += (frq[0] & 0xF0) >> 4;
+	*freq *= 10;
+	*freq += frq[0] & 0x0F;
+	*freq *= 10;
+	*freq += (frq[1] & 0xF0) >> 4;
+	*freq *= 10;
+	*freq += frq[1] & 0x0F;
+	*freq *= 10;
+	*freq += (frq[2] & 0xF0) >> 4;
+	*freq *= 10;
+	*freq += frq[2] & 0x0F;
+	*freq *= 10;
+	*freq += (frq[3] & 0xF0) >> 4;
+	*freq *= 10;
+	*freq += frq[3] & 0x0F;
+	*freq *= 10;
+	break;
+
+	case K2: case K3:
+	/* Read Rx frequency */
+	if( !Write_Tcvr_Serial(K3_VFOA_G, sizeof(K3_VFOA_G)-1) ||
+		!Read_Tcvr_Serial(K3_VFOA_S, sizeof(K3_VFOA_S)-1) )
+	  return( FALSE );
+	*freq = atoi( K3_VFOA_S + 2 );
+	break;
+
+  } /* switch( rc_data.tcvr_type ) */
+
+  return( TRUE );
+} /* End of Read_Rx_Freq() */
+
+/*------------------------------------------------------------------------*/
+
+/*  Write_Rx_Freq()
+ *
+ *  Writes the Rx freq to the Yaesu FT-847 transceiver.
+ */
+
+  static gboolean
+Write_Rx_Freq( int freq )
+{
+  /* Buffer used for converting freq. to string */
+  char freq_buff[11];
+  int idx; /* Index for loops etc */
+
+
+  /* Abort if CAT disabled */
+  if( isFlagClear(CAT_SETUP) ) return( TRUE );
+
+  switch( rc_data.tcvr_type )
+  {
+	case FT847: case FT857:
+	  /* Set Rx frequency */
+	  snprintf( freq_buff, sizeof(freq_buff), "%08d", freq/10 );
+	  for( idx = 0; idx < 4; idx++ )
+	  {
+		FT847_SET_VFO[idx]  = (char)((freq_buff[2*idx]   - '0') << 4);
+		FT847_SET_VFO[idx] |= (char)( freq_buff[2*idx+1] - '0');
+	  }
+	  if( !Write_Tcvr_Serial(FT847_SET_VFO, sizeof(FT847_SET_VFO)) )
+		return( FALSE );
+	  break;
+
+	case K2: case K3:
+	  /* Set Rx frequency */
+	  snprintf( K3_VFOA_S+2, sizeof(K3_VFOA_S)-2, "%011d;", freq );
+	  if( !Write_Tcvr_Serial(K3_VFOA_S, sizeof(K3_VFOA_S)-1) )
+		  return( FALSE );
+	  break;
+
+  } /* switch( rc_data.tcvr_type ) */
+
+  return( TRUE );
+} /* End of Write_Rx_Freq() */
+
+/*-------------------------------------------------------------------------*/
+
 /*  Open_Tcvr_Serial()
  *
  *  Opens Tcvr's Serial Port device, returns the file
@@ -57,6 +270,7 @@ Open_Tcvr_Serial( void )
   struct termios new_options; /* New serial port options */
   struct flock lockinfo;      /* File lock information   */
   int error = 0;
+  char test[5];
 
   /* Abort if serial already open */
   if( isFlagSet(CAT_SETUP) ) return( TRUE );
@@ -135,7 +349,6 @@ Open_Tcvr_Serial( void )
   Set_Flag( TCVR_SERIAL_TEST );
   switch( rc_data.tcvr_type )
   {
-	char test[5];
 	case FT847:
 	  if( !Write_Tcvr_Serial(FT847_CAT_ON, sizeof(FT847_CAT_ON)) ||
 		  !Write_Tcvr_Serial(FT847_MAIN_VFO, sizeof(FT847_MAIN_VFO)) ||
@@ -226,229 +439,6 @@ Close_Tcvr_Serial( void )
 
 /*-------------------------------------------------------------------------*/
 
-/* Cancel_CAT()
- *
- * Cancels Transceiver CAT (on error)
- */
-
-  void
-Cancel_CAT( void )
-{
-  close( serial_fd );
-  serial_fd = 0;
-  //rc_data.tcvr_type = NONE;
-  Clear_Flag( CAT_SETUP );
-  Clear_Flag( TCVR_SERIAL_TEST );
-  Error_Dialog( "Failed to Establish Transceiver CAT"  );
-}
-
-/*-------------------------------------------------------------------------*/
-
-
-/*  Read_Tcvr_Serial()
- *
- *  Reads Data from the Transceiver
- */
-
-  gboolean
-Read_Tcvr_Serial( char *data, size_t len )
-{
-  int nbytes = 0, cnt = 0;
-
-  /* Check for data to be available */
-  if( isFlagClear(TCVR_SERIAL_TEST) &&
-	  isFlagClear(CAT_SETUP) )
-	return( FALSE );
-  while( ++cnt < MAX_SERIAL_RETRIES )
-  {
-	ioctl( serial_fd, FIONREAD, &nbytes);
-	if( nbytes == (int)len ) break;
-	fprintf( stderr,
-		"xdemorse: read(): incorrect number of bytes available:"
-		" %d/%d\n", nbytes, (int)len );
-	usleep(100000);
-  }
-
-  /* Error condition */
-  if( cnt >= MAX_SERIAL_RETRIES )
-  {
-	tcflush( serial_fd, TCIOFLUSH );
-	fprintf( stderr,
-		"xdemorse: read(): incorrect number of bytes available:"
-		" %d/%d after %d tries\n", nbytes, (int)len, cnt );
-	data[0] = '\0';
-	Cancel_CAT();
-	return( FALSE );
-  }
-
-  /* Clear data buffer and read from serial */
-  size_t ret = (size_t)read( serial_fd, data, len );
-
-  /* Error condition */
-  if( ret != len )
-  {
-	tcflush( serial_fd, TCIOFLUSH );
-	fprintf( stderr,
-		"xdemorse: read() return value wrong: %d/%d\n",
-		(int)ret, (int)len );
-	data[0] = '\0';
-	Cancel_CAT();
-	return( FALSE );
-  }
-
-  return( TRUE );
-} /* End of Read_Tcvr_Serial() */
-
-/*-------------------------------------------------------------------------*/
-
-/*  Write_Tcvr_Serial()
- *
- *  Writes a command to the Tranceiver
- */
-
-  gboolean
-Write_Tcvr_Serial( char *data, size_t len )
-{
-  int cnt = 0;
-  size_t ret = 0;
-
-  /* Flush serial and write command, retrying if needed */
-  if( isFlagClear(TCVR_SERIAL_TEST) &&
-	  isFlagClear(CAT_SETUP) )
-	return( FALSE );
-  tcflush( serial_fd, TCIOFLUSH );
-  while( cnt++ < MAX_SERIAL_RETRIES )
-  {
-	ret = (size_t)write( serial_fd, data, len );
-	if( ret == len ) break;
-	fprintf( stderr,
-		"xdemorse: write(): incorrect number of bytes written:"
-		" %d/%d\n", (int)ret, (int)len );
-	usleep(100000);
-  }
-
-  /* Error condition */
-   if( cnt >= MAX_SERIAL_RETRIES )
-  {
-	tcflush( serial_fd, TCIOFLUSH );
-	fprintf( stderr,
-		"xdemorse: write(): incorrect number of bytes written:"
-		" %d/%d after %d tries\n", (int)ret, (int)len, cnt );
-	Cancel_CAT();
-	return( FALSE );
-  }
-
-  /* Give time to CAT to do its thing */
-  usleep(50000);
-  return( TRUE );
-
-} /* End of Write_Tcvr_Serial() */
-
-/*-------------------------------------------------------------------------*/
-
-/*  Read_Rx_Freq()
- *
- *  Reads the Rx freq of the Yaesu transceiver.
- */
-
-  gboolean
-Read_Rx_Freq( int *freq )
-{
-  /* A char string for sending and receiving  */
-  /* data strings to and from the transceiver */
-  char frq[5];
-
-  /* Abort if CAT disabled */
-  if( isFlagClear(CAT_SETUP) ) return( TRUE );
-
-  switch( rc_data.tcvr_type )
-  {
-	case FT847: case FT857:
-	/* Read Rx frequency */
-	memset( frq, 0, sizeof(frq) );
-	if( !Write_Tcvr_Serial(FT847_MAIN_VFO, sizeof(FT847_MAIN_VFO)) ||
-		!Read_Tcvr_Serial(frq, sizeof(frq)) )
-	  return( FALSE );
-
-	/* Decode frequency data to 10Hz */
-	*freq = 0;
-	*freq += (frq[0] & 0xF0) >> 4;
-	*freq *= 10;
-	*freq += frq[0] & 0x0F;
-	*freq *= 10;
-	*freq += (frq[1] & 0xF0) >> 4;
-	*freq *= 10;
-	*freq += frq[1] & 0x0F;
-	*freq *= 10;
-	*freq += (frq[2] & 0xF0) >> 4;
-	*freq *= 10;
-	*freq += frq[2] & 0x0F;
-	*freq *= 10;
-	*freq += (frq[3] & 0xF0) >> 4;
-	*freq *= 10;
-	*freq += frq[3] & 0x0F;
-	*freq *= 10;
-	break;
-
-	case K2: case K3:
-	/* Read Rx frequency */
-	if( !Write_Tcvr_Serial(K3_VFOA_G, sizeof(K3_VFOA_G)-1) ||
-		!Read_Tcvr_Serial(K3_VFOA_S, sizeof(K3_VFOA_S)-1) )
-	  return( FALSE );
-	*freq = atoi( K3_VFOA_S + 2 );
-	break;
-
-  } /* switch( rc_data.tcvr_type ) */
-
-  return( TRUE );
-} /* End of Read_Rx_Freq() */
-
-/*------------------------------------------------------------------------*/
-
-/*  Write_Rx_Freq()
- *
- *  Writes the Rx freq to the Yaesu FT-847 transceiver.
- */
-
-  gboolean
-Write_Rx_Freq( int freq )
-{
-  /* Buffer used for converting freq. to string */
-  char freq_buff[9];
-  int idx; /* Index for loops etc */
-
-
-  /* Abort if CAT disabled */
-  if( isFlagClear(CAT_SETUP) ) return( TRUE );
-
-  switch( rc_data.tcvr_type )
-  {
-	case FT847: case FT857:
-	  /* Set Rx frequency */
-	  snprintf( freq_buff, sizeof(freq_buff), "%08d", freq/10 );
-	  for( idx = 0; idx < 4; idx++ )
-	  {
-		FT847_SET_VFO[idx]  = (char)((freq_buff[2*idx]   - '0') << 4);
-		FT847_SET_VFO[idx] |= (freq_buff[2*idx+1] - '0');
-	  }
-	  if( !Write_Tcvr_Serial(FT847_SET_VFO, sizeof(FT847_SET_VFO)) )
-		return( FALSE );
-	  break;
-
-	case K2: case K3:
-	  /* Set Rx frequency */
-	  snprintf( K3_VFOA_S+2, sizeof(K3_VFOA_S)-2, "%011d;", freq );
-	  if( !Write_Tcvr_Serial(K3_VFOA_S, sizeof(K3_VFOA_S)-1) )
-		  return( FALSE );
-	  break;
-
-  } /* switch( rc_data.tcvr_type ) */
-
-  return( TRUE );
-} /* End of Write_Rx_Freq() */
-
-/*-------------------------------------------------------------------------*/
-
 /* Tune_Tcvr()
  *
  * Tunes the transceiver to the frequency of the strongest
@@ -461,51 +451,42 @@ Tune_Tcvr( double x )
   int
 	from, to,	/* Range to scan for a max bin value  */
 	bin_max,	/* Max bin value found in this range  */
-	max_idx,	/* fft idx at which the max is found */
-	fft_idx,	/* Idx used to search fft bin values */
+	max_idx,	/* dft idx at which the max is found */
+	dft_idx,	/* Idx used to search dft bin values */
 	tcvr_freq,	/* Transceiver's Rx frequency */
 	audio_freq;	/* Audio frequency in waterfal window */
 
   /* Abort if serial already open */
   if( isFlagClear(CAT_SETUP) ) return( TRUE );
 
-  /* Calculate fft index corresponding to pointer x in waterfall window */
-  fft_idx = (int)(x - 0.5);
+  /* Calculate dft index corresponding to pointer x in waterfall window */
+  dft_idx = (int)(x - 0.5);
 
   /* Look above and below click point for max bin val */
-  from = fft_idx - 10;
+  from = dft_idx - CLICK_TUNE_RANGE;
   if( from < 0 ) from = 0;
-  to = fft_idx + 10;
-  if( to >= gbl_wfall_width ) to = gbl_wfall_width - 1;
+  to = dft_idx + CLICK_TUNE_RANGE;
+  if( to >= wfall_width ) to = wfall_width - 1;
 
   /* Find max bin value around click point */
   bin_max = 0;
-  max_idx = fft_idx;
-  for( fft_idx = from; fft_idx < to; fft_idx++ )
-	if( bin_max < gbl_bin_ave[fft_idx] )
+  max_idx = dft_idx;
+  for( dft_idx = from; dft_idx < to; dft_idx++ )
+	if( bin_max < bin_ave[dft_idx] )
 	{
-	  bin_max = gbl_bin_ave[fft_idx];
-	  max_idx = fft_idx;
+	  bin_max = bin_ave[dft_idx];
+	  max_idx = dft_idx;
 	}
 
-  /* Audio freq. corresponding to fft index */
-  audio_freq = (2 * max_idx * rc_data.tone_freq) / gbl_wfall_width;
+  /* Audio freq. corresponding to dft index */
+  audio_freq = (2 * max_idx * rc_data.tone_freq) / wfall_width;
 
   /* Read current Rx frequency */
+  tcvr_freq = 0;
   if( !Read_Rx_Freq(&tcvr_freq) ) return( FALSE );
 
   /* Add correction according to TCVR (reverse or normal CW) */
-  switch( rc_data.tcvr_type )
-  {
-	case FT847: case FT857:
-	  tcvr_freq += audio_freq - rc_data.tone_freq;
-	  break;
-
-	case K2: case K3:
-	  tcvr_freq -= audio_freq - rc_data.tone_freq;
-	  break;
- 
-  } /* switch( rc_data.tcvr_type ) */
+  tcvr_freq += audio_freq - rc_data.tone_freq;
 
   /* Calculate and write Rx freq. to center audio on AUDIO_FREQUENCY */
   if( !Write_Rx_Freq(tcvr_freq) ) return( FALSE );
