@@ -1,7 +1,4 @@
 /*
- *  xdemorse: An application to decode Morse signals to text
- *
- *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License as
  *  published by the Free Software Foundation; either version 3 of
@@ -18,11 +15,10 @@
 #ifndef CAT_H
 #define CAT_H	1
 
+#include "common.h"
+#include "dft.h"
 #include <termios.h>
 #include <fcntl.h>
-#include "common.h"
-#include "fft.h"
-#include "support.h"
 #include <sys/ioctl.h>
 
 /* Transceiver type */
@@ -37,5 +33,9 @@ enum
 
 #define MAX_SERIAL_RETRIES	10
 
+/* Range (+/-) in pixels to look for DFT maximum
+ * when click-to-tune on waterfall by user */
+#define CLICK_TUNE_RANGE	20
+
 #endif
 
