@@ -1,12 +1,4 @@
-/*  decode.c
- *
- *  Morse code decoding functions of xdemorse application
- */
-
 /*
- *  xdemorse: An application to decode Morse code signals to text
- *
- *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License as
  *  published by the Free Software Foundation; either version 3 of
@@ -31,6 +23,84 @@ static int
 
 /*------------------------------------------------------------------------*/
 
+/*  Adapt_Decoder()
+ *
+ *  Adjusts Morse speed from measurements on the incoming signal
+ */
+
+  static void
+Adapt_Decoder( void )
+{
+  /* Calculate Morse speed */
+  if( mark_elem_cnt  &&
+	  mark_frag_cnt  &&
+	  space_elem_cnt &&
+	  space_frag_cnt )
+  {
+	if( isFlagSet(ADAPT_SPEED) )
+	{
+	  /* Estimate Morse speed from space and mark counts */
+	  int speed_err = (mark_frag_cnt + space_frag_cnt) /
+				  (mark_elem_cnt + space_elem_cnt)
+				  - rc_data.unit_elem;
+
+	  /* Morse speed limits (60-6 wpm) */
+	  if( (rc_data.unit_elem > rc_data.min_unit) && (speed_err < 0) )
+			rc_data.unit_elem--;
+	  if( (rc_data.unit_elem < rc_data.max_unit) && (speed_err > 0) )
+			rc_data.unit_elem++;
+
+	  /* Display speed in wpm */
+	  int ispeed = ( 60 * rc_data.tone_freq ) /
+		( 50 * CYCLES_PER_FRAG * rc_data.unit_elem );
+	  gtk_spin_button_set_value( speed, (gdouble)ispeed );
+
+	} /* if( isFlagSet(ADAPT_SPEED) ) */
+
+  } /* if( mark_elem_cnt && space_elem_cnt && space_frag_cnt ) */
+
+  /* Clear counters */
+  space_elem_cnt = space_frag_cnt = 0;
+  mark_elem_cnt  = mark_frag_cnt  = 0;
+
+} /* Adapt_Decoder() */
+
+/*------------------------------------------------------------------------*/
+
+/*  Hex_to_Ascii()
+ *
+ *  Converts the hex equivalent of
+ *  a Morse code character to ASCII
+ */
+
+  static char *
+Hex_to_Ascii( int *hex_code )
+{
+  /* Table of ASCII characters available in Morse code */
+  static char *
+	morse_ascii_char[NUMBER_OF_CHAR + 1] = { MORSE_ASCII_CHAR };
+
+  /* Table of hex equivalent of Morse characters */
+ static unsigned char
+	morse_hex_char[NUMBER_OF_CHAR] = { MORSE_HEX_CODE };
+
+  int idx; /* Loop index */
+
+  /* Look for a match in hex table */
+  for( idx = 0; idx < NUMBER_OF_CHAR; idx++ )
+	if( *hex_code ==  morse_hex_char[idx] )
+	  break;
+
+  /* Clear hex code after conversion */
+  *hex_code = ENTER_DOT;
+
+  /* Return ascii equivalent of hex code */
+  return( morse_ascii_char[idx] );
+
+} /* End of Hex_to_Ascii() */
+
+/*------------------------------------------------------------------------*/
+
 /*  Get_Character()
  *
  *  Decodes a Morse code character from the
@@ -54,7 +124,7 @@ Get_Character( char *chr )
 	unit_x8  = rc_data.unit_elem * 8,
 	unit_x16 = rc_data.unit_elem * 16;
 
-  /* Hex equivalent of Morse code is formed by left-shifting 1 or 0 
+  /* Hex equivalent of Morse code is formed by left-shifting 1 or 0
    * into hex_code. The ENTER_DOT (0x01) initial value marks the
    * beginning of the bit field, 1 being a dit and 0 a dash. */
 
@@ -151,7 +221,8 @@ Get_Character( char *chr )
 		  context = WAIT_WORD_SPACE;
 
 		  /* Return decoded Morse char */
-		  *chr = Hex_to_Ascii( &hex_code );
+		  char *str = Hex_to_Ascii( &hex_code );
+		  Strlcpy( chr, str, MAX_CHAR_LEN );
 		  return( TRUE );
 		}
 	  }  /* if( isFlagSet(SPACE_TONE) ) */
@@ -195,7 +266,7 @@ Get_Character( char *chr )
 	  {
 		if( space_cnt >= unit_x7 )
 		{
-		  *chr = ' ';
+		  Strlcpy( chr, " ", MAX_CHAR_LEN );
 		  context = WAIT_FOR_MARK;
 		  return( TRUE );
 		}
@@ -208,7 +279,7 @@ Get_Character( char *chr )
 		/* Switch to processing mark signal */
 		space_cnt = 0;
 		mark_cnt  = 1;
-		*chr = ' ';
+		Strlcpy( chr, " ", MAX_CHAR_LEN );
 		context = MARK_SIGNAL;
 		return( TRUE );
 	  }
@@ -246,79 +317,3 @@ Get_Character( char *chr )
 
 /*------------------------------------------------------------------------*/
 
-/*  Adapt_Decoder()
- *
- *  Adjusts Morse speed from measurements on the incoming signal
- */
-
-  void
-Adapt_Decoder( void )
-{
-  /* Calculate Morse speed */
-  if( mark_elem_cnt  &&
-	  mark_frag_cnt  &&
-	  space_elem_cnt &&
-	  space_frag_cnt )
-  {
-	if( isFlagSet(ADAPT_SPEED) )
-	{
-	  /* Estimate Morse speed from space and mark counts */
-	  int speed_err = (mark_frag_cnt + space_frag_cnt) /
-				  (mark_elem_cnt + space_elem_cnt)
-				  - rc_data.unit_elem;
-
-	  /* Morse speed limits (60-6 wpm) */
-	  if( (rc_data.unit_elem > rc_data.min_unit) && (speed_err < 0) )
-			rc_data.unit_elem--;
-	  if( (rc_data.unit_elem < rc_data.max_unit) && (speed_err > 0) )
-			rc_data.unit_elem++;
-
-	  /* Display speed in wpm */
-	  int speed = ( 60 * rc_data.tone_freq ) /
-		( 50 * CYCLES_PER_FRAG * rc_data.unit_elem );
-	  gtk_spin_button_set_value( gbl_speed, (gdouble) speed );
-
-	} /* if( isFlagSet(ADAPT_SPEED) ) */
-
-  } /* if( mark_elem_cnt && space_elem_cnt && space_frag_cnt ) */
-
-  /* Clear counters */
-  space_elem_cnt = space_frag_cnt = 0;
-  mark_elem_cnt  = mark_frag_cnt  = 0;
-
-} /* Adapt_Decoder() */
-
-/*------------------------------------------------------------------------*/
-
-/*  Hex_to_Ascii()
- *
- *  Converts the hex equivalent of
- *  a Morse code character to ASCII
- */
-
-  char
-Hex_to_Ascii( int *hex_code )
-{
-  /* Table of ASCII characters available in Morse code */
-  static char
-	morse_ascii_char[ NUMBER_OF_CHAR + 1 ] = MORSE_ASCII_CHAR;
-
-  /* Table of hex equivalent of Morse characters */
- static unsigned char
-	morse_hex_char[ NUMBER_OF_CHAR ] = MORSE_HEX_CODE;
-
-  int idx; /* Loop index */
-
-  /* Look for a match in hex table */
-  for( idx = 0; idx < NUMBER_OF_CHAR; idx++ )
-	if( *hex_code ==  morse_hex_char[ idx ] )
-	  break;
-
-  /* Clear hex code after conversion */
-  *hex_code = ENTER_DOT;
-
-  /* Return ascii equivalent of hex code */
-  return( morse_ascii_char[ idx ] );
-} /* End of Hex_to_Ascii() */
-
-/*------------------------------------------------------------------------*/
