@@ -1,12 +1,4 @@
-/*  detect.c
- *
- *  Signal detection functions of xdemorse application
- */
-
 /*
- *  xdemorse: An application to decode Morse code signals to text
- *
- *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License as
  *  published by the Free Software Foundation; either version 3 of
@@ -47,6 +39,14 @@ static struct
 
 } detector_data;
 
+static int
+  frag_level,	/* Level of audio signal over a fragment */
+  level_sum,	/* Sum of above two levels, used as squelch */
+  det_ratio;	/* Ratio of trailing edge / leading edge above */
+
+/* Points to plot on scope */
+static GdkPoint *points = NULL;
+
 /*------------------------------------------------------------------------*/
 
 /*  Get_Fragment()
@@ -63,13 +63,11 @@ Get_Fragment( void )
   int
 	block_size, /* Block size (N) of the Goertzel algorithm */
 	frag_timer, /* Counter for timing duration of fragment  */
-	frag_level,	/* Level of audio signal over a fragment */
 	lead_edge,	/* Level of signal's leading edge integrator */
 	trail_edge,	/* Level of signal's trailing edge integrator */
-	level_sum,	/* Sum of above two levels, used as squelch */
-	det_ratio,	/* Ratio of trailing edge / leading edge above */
 	ref_ratio,	/* Reference for above to determine Mark | Space */
 	state_cnt,	/* Count of the detected signal state above */
+	plot = 0,	/* Value to be plotted in xcope */
 	idx, ids;
 
   static unsigned char state; /* Current state of signal */
@@ -77,6 +75,18 @@ Get_Fragment( void )
   /* Variables for the Goertzel algorithm */
   double q0, q1, q2, level;
 
+  /* Index to points to plot on scope */
+  static int points_idx = 0;
+
+  /* Initialize on first call */
+  if( points == NULL )
+  {
+	if( !mem_alloc( (void *)&points,
+		  (size_t)scope_width * sizeof(GdkPoint)) )
+	  return( FALSE );
+  }
+
+
   /* Goertzel block size depends on Morse speed */
   block_size = detector_data.frag_len;
 
@@ -174,7 +184,7 @@ Get_Fragment( void )
 	else if( ((int)RATIO_MULTIPLIER) * trail_edge > ref_ratio * lead_edge )
 	  state = 0; /* State is a Space, e.g. no tone */
   } /* if( (lead_edge + trail_edge) > LEVEL_THRESHOLD ) */
- 
+
   /* Save Mark | Space detector state */
   detector_data.state[detector_data.state_idx] = state;
 
@@ -215,21 +225,74 @@ Get_Fragment( void )
   if( isFlagSet(DISPLAY_RATIO) )
   {
 	rc_data.det_threshold = (int)( rc_data.det_ratio * RATIO_MULTIPLIER );
-	Display_Detector( det_ratio );
+	plot = det_ratio;
   }
   else if( isFlagSet(DISPLAY_LEVEL) )
   {
 	rc_data.det_threshold = rc_data.det_squelch;
-	Display_Detector( level_sum / SQUELCH_MULTIPLIER );
+	plot = level_sum / SQUELCH_MULTIPLIER;
   }
   else if( isFlagSet(DISPLAY_SIGNAL) )
-	Display_Signal( frag_level / SIGNAL_SCALE );
+	plot = frag_level / SIGNAL_SCALE;
+
+  if( isFlagClear(SCOPE_HOLD) )
+  {
+	/* Save values to be plotted  */
+	points[points_idx].y = scope_height - plot - 1;
+	if( points[points_idx].y <= 0 )
+	  points[points_idx].y = 1;
+	if( points[points_idx].y >= scope_height )
+	  points[points_idx].y = scope_height - 1;
+	points[points_idx].x = points_idx;
+
+	/* Recycle buffer idx when full and plot */
+	points_idx++;
+	if( points_idx >= scope_width )
+	{
+	  /* Draw scope */
+	  Set_Flag( SCOPE_READY );
+	  gtk_widget_queue_draw( scope );
+	  points_idx = 0;
+	}
+  }
 
   return( TRUE );
 } /* End of Get_Fragment() */
 
 /*------------------------------------------------------------------------*/
 
+/* Display_Scope()
+ *
+ * Displays graphs in the scope display on "draw" signal
+ */
+  void
+Display_Scope( cairo_t *cr )
+{
+  if( isFlagSet(SCOPE_READY) )
+  {
+	/* Display signal or detector graph (scope) */
+	if( isFlagSet(DISPLAY_RATIO) ||
+		isFlagSet(DISPLAY_LEVEL) )
+	  Display_Detector( cr, points );
+	else if( isFlagSet(DISPLAY_SIGNAL) )
+	  Display_Signal( cr, points );
+	Clear_Flag( SCOPE_READY );
+  }
+  else /* Clear scope */
+  {
+	/* Draw scope background */
+	cairo_set_source_rgb( cr, RGB_BACKGND );
+	cairo_rectangle(
+		cr, 0.0, 0.0,
+		(double)scope_width  + 2.0,
+		(double)scope_height + 2.0 );
+	cairo_fill( cr );
+  }
+
+} /* Display_Scope() */
+
+/*------------------------------------------------------------------------*/
+
 /* Initialize_Detector()
  *
  * Initializes variables and allocates buffers
@@ -265,7 +328,7 @@ Initialize_Detector( void )
   /* Allocate samples buffer */
   detector_data.samples_buff = NULL;
   alloc = (size_t)detector_data.samples_buff_len * sizeof(short);
-  if( !mem_alloc((void *)&detector_data.samples_buff, alloc) )
+  if( !mem_alloc((void **)&detector_data.samples_buff, alloc) )
 	return( FALSE );
 
   /* Clear buffer */
@@ -275,7 +338,7 @@ Initialize_Detector( void )
   /* Allocate signal level (Goerstzel detector o/p) buffer */
   detector_data.sig_level_buff = NULL;
   alloc = (size_t)rc_data.max_unit_x2 * sizeof(int);
-  if( !mem_alloc( (void *)&detector_data.sig_level_buff, alloc) )
+  if( !mem_alloc( (void **)&detector_data.sig_level_buff, alloc) )
 	return( FALSE );
 
   /* Clear buffer */
@@ -285,7 +348,7 @@ Initialize_Detector( void )
   /* Allocate signal level (Goerstzel detector o/p) buffer */
   detector_data.state = NULL;
   alloc = (size_t)rc_data.max_unit;
-  if( !mem_alloc( (void *)&detector_data.state, alloc) )
+  if( !mem_alloc( (void **)&detector_data.state, alloc) )
 	return( FALSE );
 
   /* Clear buffer */
