@@ -1,12 +1,4 @@
-/*  detect.h
- *
- *  Header file for detect.c
- */
-
 /*
- *  xdemorse: An application to decode Morse signals to text
- *
- *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License as
  *  published by the Free Software Foundation; either version 3 of
@@ -25,11 +17,12 @@
 
 #include <math.h>
 #include "common.h"
+#include "display.h"
 
 /* Minimum level of lead+trail edge of tone over
  * which the tone detector looks for mark or space */
 #define CYCLES_PER_FRAG		2		/* Cycles of signal/signal fragment  */
-#define SIGNAL_SCALE		90		/* Scale factor to fit signal in scope */
+#define SIGNAL_SCALE		45		/* Scale factor to fit signal in scope */
 #define SQUELCH_MULTIPLIER	150		/* Multiplier for the squelch threshold */
 #define RATIO_MULTIPLIER	20.0	/* Multiplier for the ratio threshold */
 
