@@ -1,7 +1,4 @@
 /*
- *  xdemorse: An application to decode Morse signals to text
- *
- *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License as
  *  published by the Free Software Foundation; either version 3 of
@@ -19,8 +16,18 @@
 #define DISPLAY_H	1
 
 #include "common.h"
-#include "fft.h"
+#include "dft.h"
+#include "decode.h"
 
-#define BINMAX_AVE_WIN    2 /* Length of bin max averaging window  */
+/* Length and multiplier of amplitude averaging window  */
+#define AMPL_AVE_WIN		2
+#define AMPL_AVE_MUL		1
+
+/* Some colors used in plotting */
+#define RGB_GREEN		0.0, 1.0, 0.0
+#define RGB_BACKGND		0.0, 0.2, 0.0
+#define RGB_WHITE		1.0, 1.0, 1.0
+
+#define CAIRO_LINE_WIDTH	1.5
 
 #endif
