@@ -20,16 +20,7 @@
 
 #include "common.h"
 #include "interface.h"
-#include "support.h"
-#include "fft.h"
-#include "sound.h"
-#include "decode.h"
-#include "cat.h"
-
-/* Special characters */
-#define LF      0x0A /* Line Feed */
-#define CR      0x0D /* Carriage Return */
-#define HT      0x09 /* Horizontal Tab  */
+#include "dft.h"
 
 #endif
 
