@@ -1,13 +1,4 @@
-/*  sound.c
- *
- *  Soundcard handling functions of xdemorse application
- */
-
 /*
- *  xdemorse: An application to decode and display
- *  Morse code signals using a computer's sound card
- *
- *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License as
  *  published by the Free Software Foundation; either version 3 of
@@ -281,8 +272,7 @@ Setup_Sound_Card( char *mesg, int *error )
   *error = snd_pcm_prepare( capture_handle );
   if( *error < 0 )
   {
-	Strlcat( mesg,
-		_("Cannot prepare audio interface"), MESG_SIZE );
+	Strlcat( mesg,	_("Cannot prepare audio interface"), MESG_SIZE );
 	return( FALSE );
   }
 
@@ -316,78 +306,11 @@ Close_Mixer_Handle( void )
 
 /*------------------------------------------------------------------------*/
 
-/*  Get_Signal_Sample()
- *
- *  Gets the next DSP sample of the signal input
- */
-
-  gboolean
-Signal_Sample( short *sample )
-{
-  snd_pcm_sframes_t error;
-
-  static int
-	fft_idx = 0, /* fft input buffer idx */
-	cnt = 0;	 /* Count of calls to this function */
-
-
-  /* Refill dsp samples buffer when needed */
-  if( samples_buffer.buffer_idx >= samples_buffer.buffer_size )
-  {
-	/* Start buffer index according to channel */
-	samples_buffer.buffer_idx = rc_data.use_chnl;
-
-	/* Read audio samples from DSP, abort on error */
-	error = snd_pcm_readi(
-		capture_handle, samples_buffer.buffer,	READI_FRAMES );
-	if( error != READI_FRAMES )
-	{
-	  char mesg[MESG_SIZE];
-	  snprintf( mesg, sizeof(mesg),
-		  _("Read from audio interface failed\n"\
-			"Error: %s\n"), snd_strerror((int)error) );
-	  fprintf( stderr, "%s", mesg );
-
-	  /* Try to recover if broken pipe or suspend */
-	  if( !Xrun_Recovery((int)error) )
-	  {
-		Cleanup();
-		return( FALSE );
-	  }
-	}
-  } /* End of if( buffer_idx >= buffer_size ) */
-
-  /* Get a sample from the buffer in short form */
-  *sample = samples_buffer.buffer[samples_buffer.buffer_idx];
-
-  /* Take a sample for the FFT and reset stride counter */
-  if( ++cnt >= rc_data.fft_stride )
-  {
-	fft_in_r[fft_idx]  = *sample;
-	fft_idx++;
-	cnt = 0;
-  }
-
-  /* Display waterfall when input buffer full */
-  if( fft_idx >= FFT_INPUT_SIZE )
-  {
-	fft_idx = 0;
-	Display_Waterfall();
-  }
-
-  /* Increment according to mono/stereo mode */
-  samples_buffer.buffer_idx += rc_data.num_chnl;
-
-  return( TRUE );
-} /* Signal_Sample() */
-
-/*------------------------------------------------------------------------*/
-
 /* Xrun_Recovery()
  *
  * Recover from underrun (broken pipe) and suspend
  */
-  gboolean
+  static gboolean
 Xrun_Recovery( int error )
 {
   if( error == -EPIPE )
@@ -427,3 +350,78 @@ Xrun_Recovery( int error )
 
 /*------------------------------------------------------------------------*/
 
+/*  Get_Signal_Sample()
+ *
+ *  Gets the next DSP sample of the signal input
+ */
+
+  gboolean
+Signal_Sample( short *sample )
+{
+  snd_pcm_sframes_t error;
+
+  static int
+	dft_idx = 0, /* dft input buffer idx */
+	cnt     = 0; /* Count of calls to this function */
+
+
+  /* Refill dsp samples buffer when needed */
+  if( samples_buffer.buffer_idx >= samples_buffer.buffer_size )
+  {
+	/* Start buffer index according to channel */
+	samples_buffer.buffer_idx = rc_data.use_chnl;
+
+	/* Read audio samples from DSP, abort on error */
+	error = snd_pcm_readi(
+		capture_handle, samples_buffer.buffer,	READI_FRAMES );
+	if( error != READI_FRAMES )
+	{
+	  char mesg[MESG_SIZE];
+	  snprintf( mesg, sizeof(mesg),
+		  _("Read from audio interface failed\n"\
+			"Error: %s\n"), snd_strerror((int)error) );
+	  fprintf( stderr, "%s", mesg );
+
+	  /* Try to recover if broken pipe or suspend */
+	  if( !Xrun_Recovery((int)error) )
+	  {
+		Cleanup();
+		return( FALSE );
+	  }
+	}
+  } /* End of if( buffer_idx >= buffer_size ) */
+
+  /* Get a sample from the buffer in short form */
+  *sample = samples_buffer.buffer[samples_buffer.buffer_idx];
+
+  /* Summate (decimate) samples for the DFT */
+  dft_in_r[dft_idx] += *sample;
+
+  /* Reset stride (decimation) counter */
+  if( ++cnt >= rc_data.dft_stride )
+  {
+	cnt = 0;
+
+	/* Normalize DFT input samples */
+	dft_in_r[dft_idx] /= rc_data.dft_stride;
+	dft_idx++;
+
+	/* Display waterfall when input buffer full */
+	if( dft_idx >= DFT_INPUT_SIZE )
+	{
+	  Display_Waterfall();
+	  dft_idx = 0;
+	}
+
+	/* Clear for next summation */
+	dft_in_r[dft_idx] = 0;
+  }
+
+  /* Increment according to mono/stereo mode */
+  samples_buffer.buffer_idx += rc_data.num_chnl;
+
+  return( TRUE );
+} /* Signal_Sample() */
+
+/*------------------------------------------------------------------------*/
+
