@@ -1,7 +1,4 @@
 /*
- *  xdemorse: An application to decode Morse signals to text
- *
- *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License as
  *  published by the Free Software Foundation; either version 3 of
@@ -20,12 +17,11 @@
 
 #include <alsa/asoundlib.h>
 #include "common.h"
-#include "fft.h"
-#include "support.h"
+#include "dft.h"
 
 #define READI_FRAMES	512	 /* Number of frames to read from dsp */
-#define PERIOD_SIZE		8192 /* Period size of dsp in frames */
-#define NUM_PERIODS		2	 /* Number of periods */
+#define PERIOD_SIZE		4096 /* Period size of dsp in frames */
+#define NUM_PERIODS		4	 /* Number of periods */
 #define EXACT_VAL		0	 /* Set excat value of hwparams */
 
 #endif
