@@ -1,13 +1,4 @@
-/*  utils.c
- *
- *  Utility functions for the xdemorse application
- */
-
 /*
- *  xdemorse: An application to decode and display
- *  Morse code signals using the computer's sound card.
- *
- *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License as
  *  published by the Free Software Foundation; either version 3 of
@@ -25,6 +16,14 @@
 #define UTILS_H		1
 
 #include "common.h"
-#include "support.h"
+#include "interface.h"
+#include "shared.h"
+#include "sound.h"
+#include "cat.h"
+
+/* Special characters */
+#define LF      0x0A /* Line Feed */
+#define CR      0x0D /* Carriage Return */
+#define HT      0x09 /* Horizontal Tab  */
 
 #endif
